<?php
/**
 * Vehicle Series Class
 *
 * This class communicates with the CTR database and retrieves the SERIES
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-ctr-db.php';

class Ctr_Series {

    private $helper;
    private $vehicle_type;
    private $use_cache;

    /**
	 * Initialize the class and set its properties.
	 *
	 * @since    3.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($vehicle_type = 'cars') {
		$this->helper = new Ctr_Helpers();
        $this->database = new Ctr_DB();
        $this->use_cache = $this->database->getSettings()['enable_cache'];
        $this->vehicle_type = $this->helper->translate_vehicle_type($vehicle_type);
    }
    

    public function getSeries($brandId = NULL, $brandSlug = NULL) {
        if (isset($brandId) || isset($brandSlug)) {
            $cacheCode = $this->vehicle_type . '_series_' . base64_encode($brandId . '_' . $brandSlug);
            $serieCache = $this->helper->get_cache($cacheCode);
            
            
            if(false !== $serieCache && $this->use_cache == 1) {
                return $serieCache;
            }

            $url = (isset($brandSlug)) ? API_SEARCH_URL . '?type='. $this->vehicle_type .'&brand_slug=' . $brandSlug : API_URL . 'series?brand_id=' . $brandId;
            $response = wp_remote_get(
                    $url, array(
                        'body' => '',
                        'timeout' => 30,
                        'headers' => [
                        'Authorization' => 'Bearer ' . $this->database->getApiKey()
                    ]
                )
            );
            
            if (is_wp_error( $response )) {
               $error_message = $response->get_error_message();
               echo "Something went wrong: $error_message";
            } else {
               $responseData = json_decode($response['body'], true);
               $this->helper->set_cache($cacheCode, $responseData, 'ctr', 180); // Save our brands for at least 30 days
               return $responseData;
            }
        }
    }

}