<?php

/**
 * Functionality helpers
 *
 * This SEO class adds SEO specific functionalities
 *
 * @since      3.3.9.6
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
class CTR_SEO {
    private $tagline;
    private $seo_data;
    private $catalog_seo_settings;

    public function __construct()
    {
        global $wpdb;
        $catalogSettings= $wpdb->get_row("SELECT * FROM {$wpdb->prefix}chiptuningreseller WHERE id=1");
        if(isset($catalogSettings->seo_settings)) {
            $this->catalog_seo_settings = json_decode($catalogSettings->seo_settings);
        }
    }
    /** Set tagline */
    public function set_title($tagline)
    {
        $this->tagline = $tagline;
        return $tagline;
    }

    /* Get the title with 'specifications for' text */
    public function get_title()
    {
        if(isset($this->seo_data['stages'])) {
            $title = $this->custom_stage_title($this->seo_data);
        }
        elseif(isset($this->seo_data['buildName'])) {
            $title = $this->custom_build_title($this->seo_data);
        }
        elseif(isset($this->seo_data['serieName'])) {
            $title = $this->custom_serie_title($this->seo_data);
        }
        elseif(isset($this->seo_data['brandName'])) {
            $title = $this->custom_brand_title($this->seo_data);
        }
        
        if(isset($title)) {
            return $title;
        } else {
            if(strlen($this->tagline) > 1) {
                return get_bloginfo('name') . ' - ' . __("Specifications for", "chiptuningreseller") . ' ' . $this->tagline;
            }
            return get_bloginfo('name') . ' - ' . __("Chiptuning - select your vehicle", "chiptuningreseller");
        }
    }

    /** We want to set a custom title which we have set in our Admin section */
    public function custom_brand_title($data) {        
        if(isset($this->catalog_seo_settings)) {
            $custom_title_data = $this->catalog_seo_settings;
            if((isset($custom_title_data->brand)) && (isset($custom_title_data->brand->title)) && (strlen($custom_title_data->brand->title) > 0)) {
                return str_replace(['%BLOG_NAME%', '%VEHICLE_TYPE%', '%BRAND_NAME%'],[get_bloginfo('name'), $data['translated_vehicle_type'], $data['brandName']], $custom_title_data->brand->title);
            }
        }
        return get_bloginfo('name') . ' - ' . __("Specifications for", "chiptuningreseller") . ' ' . $data['brandName'];
    }

    public function custom_serie_title($data) {
        if(isset($this->catalog_seo_settings)) {
            $custom_title_data = $this->catalog_seo_settings;
            if((isset($custom_title_data->serie)) && (isset($custom_title_data->serie->title)) && (strlen($custom_title_data->serie->title) > 0)) {
                return str_replace(['%BLOG_NAME%', '%VEHICLE_TYPE%', '%BRAND_NAME%', '%SERIE_NAME%'],[get_bloginfo('name'), $data['translated_vehicle_type'], $data['brandName'], $data['serieName']], $custom_title_data->serie->title);
            }
        }
        return get_bloginfo('name') . ' - ' . __("Specifications for", "chiptuningreseller") . ' ' . $data['brandName'] . ' ' . $data['serieName'];
    }

    public function custom_build_title($data) {
        if(isset($this->catalog_seo_settings)) {
            $custom_title_data = $this->catalog_seo_settings;
            if((isset($custom_title_data->build)) && (isset($custom_title_data->build->title)) && (strlen($custom_title_data->build->title) > 0)) {
                return str_replace(['%BLOG_NAME%', '%VEHICLE_TYPE%', '%BRAND_NAME%', '%SERIE_NAME%', '%BUILD_NAME%'],[get_bloginfo('name'), $data['translated_vehicle_type'], $data['brandName'], $data['serieName'], $data['buildName']], $custom_title_data->brand->title);
            }
        }
        return get_bloginfo('name') . ' - ' . __("Specifications for", "chiptuningreseller") . ' ' . $data['brandName'] . ' ' . $data['serieName'] . ' ' . $data['buildName'];
    }

    public function custom_stage_title($data) {
        if(isset($this->catalog_seo_settings)) {
            $custom_title_data = $this->catalog_seo_settings;
            if((isset($custom_title_data->stage)) && (isset($custom_title_data->stage->title)) && (strlen($custom_title_data->stage->title) > 0)) {
                return str_replace(['%BLOG_NAME%', '%VEHICLE_TYPE%', '%BRAND_NAME%', '%SERIE_NAME%', '%BUILD_NAME%', '%ENGINE_NAME%', '%FUEL_TYPE%', '%ENGINE_POWER_HP%'],[get_bloginfo('name'), $data['translated_vehicle_type'], $data['brandName'], $data['serieName'], $data['buildName'], $data['stages']['vehicle']['engine']['name'], $data['engineFuelType'], $data['engineHpOriginal']], $custom_title_data->stage->title);
            }
        }
        return get_bloginfo('name') . ' - ' . __("Specifications for", "chiptuningreseller") . ' ' . $data['brandName'] . ' ' . $data['serieName'] . ' ' . $data['buildName'] . ' ' . $data['stages']['vehicle']['engine']['name'] . ' ' . $data['stages']['vehicle']['engine']['fuel_type'];
        
    }

    /**
     * Set the correct titles with Yoast (if active)
     *
     * @return void
     */
    public function set_seo_titles($data)
    {
        $this->set_seo_data($data);

        add_filter('document_title_parts', function () {
            return ['tagline' => $this->get_title()];
        }, 10);

        /** YOAST functionalities for adding custom titles and descriptions **/
        add_filter('wpseo_title', function () {
            return $this->get_title();
        }, 10);
        add_filter('wpseo_opengraph_title', function () {
            return $this->get_title();
        }, 10);
        add_filter('wpseo_opengraph_url', function () {
            return $this->get_url();
        }, 10);
        add_filter('wpseo_opengraph_desc', function () {
            return $this->get_title();
        }, 10);
        add_filter('wpseo_opengraph_image', function () {
            return false;
        }, 10);
        add_filter('wpseo_twitter_description', function () {
            return $this->get_title();
        }, 10);
    }

    public function set_seo_data($data) {
        $this->seo_data = $data;
    }

    /** Get the URL of the current request **/
    public function get_url()
    {
        global $wp;
        $current_url = home_url(add_query_arg(array(), $wp->request));
        return $current_url;
    }

}