<?php

/**
 * Display functionalities
 *
 * This class display functions
 *
 * @since      3.0.0
 * @package    Ctr
 * @subpackage Ctr/includes
 * @author     M Bos <support@chiptuningreseller.com>
 */
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-db.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-helpers.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-media.php';
require_once plugin_dir_path(dirname(__DIR__)) . 'includes/class-ctr-templator.php';

class Ctr_StageData
{
    private $injectData;
    private $helpers;
    private $db;
    private $media;
    private $settings;
	
    public function __construct($settings) {
		$this->helpers = new Ctr_Helpers();
		$this->db = new Ctr_DB();
        $this->media = new CTR_Media();
        $this->settings = $settings;
    }

    public function prepareChartData($data) {
        $chartData = [];
        
        foreach ($data['stageDisplayData'] as $stage) {
            
            if(!isset($this->settings['layout_settings']['graph_display'])) {
                $showGraphForStage = true;
            } else {
                
                $showGraphForStage = ((is_array($stage)) && (isset($this->settings['layout_settings'])) && 
                (isset($this->settings['layout_settings']['graph_display'])) && 
                (isset($this->settings['layout_settings']['graph_display'][$stage['name']]))) 
                ? $this->settings['layout_settings']['graph_display'][$stage['name']] : false;
            }
            if ((isset($stage['name'])) && (strpos($stage['name'], 'dsg') === false && strpos($stage['name'], 'extra') === false && strlen($stage['display_name']) > 1) && $showGraphForStage) {
                $chartData[$stage['name']]['slug'] = $stage['name'];
                $chartData[$stage['name']]['label'] = $stage['display_name'];
                $chartData[$stage['name']]['hpOriginal'] = $data['engine']['hp'];
                $chartData[$stage['name']]['hpData'] = $stage['hp_tuning'];
                $chartData[$stage['name']]['nmOriginal'] = $stage['nm_ori'];
                $chartData[$stage['name']]['nmData'] = $stage['nm_tuning'];

                $chartData[$stage['name']]['dataHpBgColor_tuning'] = $this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['hp']) ;
                $chartData[$stage['name']]['dataHpBorderColor_tuning'] = $this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['hp']);
                $chartData[$stage['name']]['dataNmBgColor_tuning'] = $this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['nm']);
                $chartData[$stage['name']]['dataNmBorderColor_tuning'] =$this->helpers->rgbaConverter($this->settings['layout_settings']['graph_colors']['tuning']['nm']);
                $chartData[$stage['name']]['dataHpBgColor_original'] = $this->settings['layout_settings']['graph_colors']['original']['hp'];
            }
        }

        return $chartData;
    }

    public function prepareData($data)
    {
        $this->settings['connection_valid'] = $this->helpers->check_api_connection();
        $stageContent = [];
        $stageMedia = [];
        $stageMediaData = [];
        $imageGalleryData = '';
        $dataStageTableButtons = [];
        $hideStage = '';
        $vehicleName = $data['stages']['vehicle']['brand']['name'] . ' ' . $data['stages']['vehicle']['serie']['name'] . ' (' . $data['stages']['vehicle']['build']['name'] . ') ' . $data['stages']['vehicle']['engine']['name'] . ' ' . $this->helpers->translate_fuel_type('lbl_fuel_' . $data['stages']['vehicle']['engine']['fuel_type'], $this->settings['display_lang']);
        $inDevelopment = false;
        $i = 0; $numberOfStages = 0;

        /** Check if the SERIE is set and add serie images where possible */
        if (isset($data['stages']['vehicle']['serie'])) {
            $serie = $data['stages']['vehicle']['serie'];
            
            if ((isset($serie['media'])) && (count($serie['media']) > 0)) {
                foreach($serie['media'] as $serieMediaItem){
                    if(isset($data['translated_vehicle_type'])) {
                        $imageGalleryData .= '<div class="col"><a href="' . $this->media->get_media($serieMediaItem['id'], 'series', $data['translated_vehicle_type'], 'large') . '" data-featherlight="image"><img class="stageImage col pull-left rounded mx-auto" src="' . $this->media->get_media($serieMediaItem['id'], 'series', $serieMediaItem['translated_vehicle_type'], 'large') . '" alt="' . $vehicleName . '" title="' . $vehicleName . '"></a></div>';
                    }
                }
            } else {
                $masterImage = $this->media->get_model_media('series', $serie['id'], 'medium', $data['translated_vehicle_type']);
                if ($masterImage) {
                    $imageGalleryData .= '<img class="stageImage rounded mx-auto" src="' . $masterImage . '" alt="' . $vehicleName . '" title="' . $vehicleName . '">';
                } elseif (!$masterImage) {
                    $noImage = $this->helpers->getAssetsUrl() . $data['translated_vehicle_type'] . '_placeholder.png';
                    $imageGalleryData .= '<img class="stageNoImage rounded mx-auto d-block" src="' . $noImage . '" alt="' . $vehicleName . '" title="' . $vehicleName . '">';
                }
            }
        }
        if(isset($data['stages']['engine'])) {
            $data['engine'] = $data['stages']['engine'];
            $nm_ori = $this->helpers->array_key_search_r($data['stages'], 'nm_ori');
            if(isset($nm_ori)) {
                $data['engine']['nm'] = $nm_ori;
            }
            unset($data['engine']['stages']); // stage data not needed in engine
        }
        
        /** Prepare the stages for display **/
        foreach ($data['stages']['stages'] as &$stage) {
            if(strpos($stage['name'], 'dsg') !== false) {
                $stage['name'] = 'stage_dsg';
            }
            $stage['show'] = ((isset($this->settings['show_stages'][$stage['name']])) && ($this->settings['show_stages'][$stage['name']] == '1')) ? true : false;
            $stage['hideCss'] = $hideStage;
            $stage['price'] = (isset($this->settings['fixed_stage_prices'][$data['stages']['vehicle']['brand']['type']][$stage['name']]) && ($this->settings['fixed_stage_prices'][$data['stages']['vehicle']['brand']['type']][$stage['name']] > 0))  ? $this->settings['fixed_stage_prices'][$data['stages']['vehicle']['brand']['type']][$stage['name']] : $stage['price'];
            
            $stage['in_development'] = strpos($stage['text_other'], 'in_development') !== false ? true : false;

            if (is_array($stage['data'])) {
                $stage['hp_percentage_increase'] = isset($stage['data']['hp_tuning']) ? $this->helpers->calculatePercentageIncrease($stage['data']['hp_ori'], $stage['data']['hp_tuning']) : null;
                $stage['nm_percentage_increase'] = isset($stage['data']['nm_tuning']) ? $this->helpers->calculatePercentageIncrease($stage['data']['nm_ori'], $stage['data']['nm_tuning']) : null;
                if (isset($stage['media'])) {
                    array_push($stageMedia, $stage['media']);
                }
                if (isset($stage['content'])) {
                    array_push($stageContent, $stage['content']);
                }

                 /*** Render the Basic Stage Table data to be inserted in the template */
                if (isset($this->settings['layout_settings']['show_basic_table'])) {
                    if (!isset($stage['name'])) {
                    } else {
                        $stage['name'] = stripos($stage['name'], 'dsg') !== false ? 'stage_dsg' : $stage['name'];

                        $showStage = ((isset($this->settings['show_stages'][$stage['name']])) && ($this->settings['show_stages'][$stage['name']] == '1')) ? true : false;
                        if (strpos($stage['name'], 'extra') === false && $showStage) {
                            $numberOfStages++;
                            $dataStageTableButtons[$i]['name'] = $stage['name'];
                            $dataStageTableButtons[$i]['fuel_type'] = $data['stages']['vehicle']['engine']['fuel_type'];
                            $dataStageTableButtons[$i]['display_name'] = $stage['display_name'];
                            $dataStageTableButtons[$i]['hp_increase'] = (isset($stage['data']['hp_tuning']) && isset($stage['data']['hp_ori'])) ? $stage['data']['hp_tuning'] - $stage['data']['hp_ori'] : '';
                            $hideStage = ' hideStage';
                        }
                    }
                    
                }
                $i++;

            }
            if (strpos($stage['text_other'], 'in_development') !== false) {
                $inDevelopment = true; // IN DEVELOPMENT ON STAGE LEVEL
            }
        }

        if(isset($stageMedia[0])) {
            foreach ($stageMedia[0] as $image) {
                $src = $this->media->get_media($image['id'], 'stages', NULL, 'large');
                $stageMediaData[] = '<div class="col stageImage"><a href="' . $src . '" data-featherlight="image"><img class="stageSmallImage" src="' . $src . '" alt="' . $image[0]['name'] . '" data-caption="" data-src="' . $src . '" data-large_image="' . $src . '" ></a></div>';
            }
        }
        
        $showBarChart = ((isset($this->helpers->check_api_connection()['options']['graphs'])) && ($this->helpers->check_api_connection()['options']['graphs'] == true) && isset($this->settings['layout_settings']['show_graph']['barchart']) && !$inDevelopment) ? true : false;
        $showLineChart = ((isset($this->helpers->check_api_connection()['options']['graphs'])) && ($this->helpers->check_api_connection()['options']['graphs'] == true) && isset($this->settings['layout_settings']['show_dyno']) && !$inDevelopment) ? true : false;
        $showPieChart = ((isset($this->helpers->check_api_connection()['options']['graphs'])) && ($this->helpers->check_api_connection()['options']['graphs']== true) && isset($this->settings['layout_settings']['show_graph']['piechart']) && !$inDevelopment) ? true : false;
        if($showBarChart || $showLineChart || $showPieChart) {
            $chartData = $this->prepareChartData($data);
        } else {
            $chartData = '';
        }
        
        $showBasicTable = isset($this->settings['layout_settings']['show_basic_table']) ?? false;
        $showIncreaserTable = isset($this->settings['layout_settings']['show_increaser_table']) ?? false;
        $showEcuDetails = isset($this->settings['layout_settings']['show_ecu_info']) ?? false;
        $showPrices = ((isset($this->settings['show_price'])) && ($this->settings['show_price'] == 1)) ? true : false;
        $ecuDetails = (isset($data['stages']['vehicle']['ecudetails'])) ? $data['stages']['vehicle']['ecudetails'] : [];
        
        $this->injectData = [
            'isFirstButton' => 'active',
            'stageDisplayData' => $data['stageDisplayData'],
            'ecuDetails' => $ecuDetails,
            'urlAssets' => $this->helpers->getAssetsUrl(),
            'configShowBasicTable' => $showBasicTable,
            'configShowIncreaserTable' => $showIncreaserTable,
            'configShowEcuDetails' => $showEcuDetails,
            'configShowBarChart' => $showBarChart,
            'configShowLineChart' => $showLineChart,
            'configShowPieChart' => $showPieChart,
            'dataEngine' => $data['engine'],
            'dataStages' => $data['stages']['stages'],
            'dataBasicTableButtons' => $dataStageTableButtons,
            'showPrices' => $showPrices,
            'dataStageMedia' => $stageMediaData,
            'dataStageContent' => $stageContent,
            'backUrl' => $data['backUrl'],
            'dataImageGallery' => $imageGalleryData,
            'dataShortcode' => str_replace('%VEHICLE_DATA%', $vehicleName, do_shortcode(stripslashes($this->settings['stage_text']))),
            'dataCharts' => $chartData,
            'numberOfStages' => $numberOfStages > 0 ? $numberOfStages : 1,
            'imgBrandImage' => isset($data['brandImage']) ? $data['brandImage'] : '',
            'engineFuelType' => $this->helpers->translate_fuel_type('lbl_fuel_' . $data['stages']['vehicle']['engine']['fuel_type'], $this->settings['display_lang']),
            'engineId' =>  $data['engine']['id'],
            'engineHpOriginal' =>  $data['stages']['vehicle']['engine']['hp'],
            /** Labels and texts */
            'lblPageTitle' => esc_html__("Chiptuning for", 'ctr'),
            'lblSubtitle' => esc_html__("Chiptuning for", 'ctr'),
            'lblVehicleBrandName' => $data['stages']['vehicle']['brand']['name'],
            'lblVehicleSerieName' => $data['stages']['vehicle']['serie']['name'],
            'lblVehicleBuildName' => $data['stages']['vehicle']['build']['name'],
            'lblVehicleEngineName' => $data['stages']['vehicle']['engine']['name'],
            'lblStandardText' => esc_html__("Standard", 'ctr'),
            'lblStageText' => esc_html__("Stage", 'ctr'),
            'lblDifference' => esc_html__("Difference", 'ctr'),
            'lblPower' => esc_html__('Power (HP)', 'ctr'),
            'lblPowerShort' => esc_html__('HP', 'ctr'),
            'lblTorque' => esc_html__('Torque (Nm)', 'ctr'),
            'lblTorqueShort' => esc_html__('Nm', 'ctr'),
            'lblKilowatt' => esc_html__("Kilowatt (KW)", 'ctr'),
            'lblShortKilowatt' => esc_html__("KW", 'ctr'),
            'lblCurrency' => $this->settings['currency'],
            'lblAskForPrice' => esc_html__("Ask for price", 'ctr'),
            'lblInDevelopment' => esc_html__("In development", 'ctr'),
            'lblPrice' => esc_html__("Price", 'ctr'),
            'lblFuelType' =>  esc_html__("Fuel type", 'ctr'),
            'lblVehicleType' => $data['vehicle_type'],
            'lblVehicleTypeInternal' => $data['translated_vehicle_type'],
        ];
    }

    public function getData() {
        return $this->injectData;
    }
}
